from google import genai
from google.genai import types
from groq import Groq
from openai import OpenAI
import os

def read_prompts_from_file(filename, delimiter):
    """Reads a file and splits the content into prompts based on the delimiter."""
    with open(filename, "r", encoding="utf-8") as file:
        text = file.read()
    return [prompt.strip() for prompt in text.split(delimiter) if prompt.strip()]

def call_gemini(prompt):
    """Call Gemini API and return the response."""
    try:
        client = genai.Client(api_key=os.environ["GEMINI_API_KEY"])

        response = client.models.generate_content(
            model="gemini-2.0-flash",
            contents=prompt,
            config=types.GenerateContentConfig(temperature=0.0)
        )

        return response.text

    except Exception as e:
        return f"Gemini API error: {e}"

def call_Qwen(prompt):
    """Call Qwen via Groq and return the response."""
    try:
        client = Groq(api_key=os.environ.get("GROQ_API_KEY"))

        response = client.chat.completions.create(
        model="qwen-2.5-32b",
        messages=[{"role": "user", "content": prompt}],
        temperature=0.0,
        )

        return response.choices[0].message.content

    
    except Exception as e:
        return f"Groq API error: {e}"
    
def call_llama(prompt):
    """Call Llama via Hyperbolic and return the response."""
    try:
        client = OpenAI(api_key=os.environ.get("HYPERBOLIC_API_KEY"), base_url="https://api.hyperbolic.xyz/v1")

        response = client.chat.completions.create(
        model="meta-llama/Meta-Llama-3-70B-Instruct",
        messages=[{"role": "user", "content": prompt}],
        temperature=0.0,
        )

        return response.choices[0].message.content

    except Exception as e:
        return f"Hyperbolic API error: {e}"
    
if __name__ == "__main__":
    input_filename = 'prompts\\summeval\\base_prompts.txt'
    output_folder = os.path.dirname(input_filename)
    detailed_prompts = os.path.join(output_folder, "detailed_prompts.txt")
    prompts = read_prompts_from_file(input_filename, delimiter="\n\n\n")

    with open(detailed_prompts, "w", encoding="utf-8") as output_file:
        for i, prompt in enumerate(prompts, start=1):
            output_file.write(f"\nPrompt {i}\n")
            output_file.write(f"{prompt}\n")

            gemini_response = call_gemini(prompt)
            output_file.write("\nGemini Response\n")
            output_file.write(f"{gemini_response}\n")

            qwen_response = call_Qwen(prompt)
            output_file.write("\nQwen Response\n")
            output_file.write(f"{qwen_response}\n")

            llama_response = call_llama(prompt)
            output_file.write("\nLlama Response\n")
            output_file.write(f"{llama_response}\n")